/*
 *  file      : src/ntb_kernel.c
 *  project   : b2im
 *  copyright : (C) 2015 by BULIN Claude
 * 
 *  This file is part of b2im project
 * 
 *  b2im is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; version 3.
 * 
 *  b2im is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 *  USA
 */
 
// ---------------------------------------
// #define NOTEBOOK_INIT_PACKAGES	0
// #define NOTEBOOK_DESKTOP			1
// #define NOTEBOOK_KERNEL			2 <---
// #define NOTEBOOK_PACKAGE			3
// #define NOTEBOOK_GFXBOOT			4
// #define NOTEBOOK_TO_HOME			5
// #define NOTEBOOK_GENERATE		6
// ---------------------------------------

#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_b2im/lib.h"
#endif

#include "global.h"
#include "configuser.h"



void on_radiobutton_iso_xx_bits_realize( GtkWidget *widget, gpointer user_data )
{
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("radiobutton_iso_32_bits")) ) {
		if( 32 == Config.choice_kernel_XX_bits )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	}
	else {
		if( 64 == Config.choice_kernel_XX_bits )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	}
}
// 
// 
void on_combobox_type_image_realize( GtkWidget *widget, gpointer user_data )
{
	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "stable" );
	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "testing" );
	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "unstable" );
	gtk_combo_box_set_active( GTK_COMBO_BOX(widget), Config.choice_type_image );
}
// 
// 
void on_combobox_choice_kernel_realize( GtkWidget *widget, gpointer user_data )
{
	FILE	*fp;
	gchar buf[256];
	gchar *Ptr = NULL;
	
	// Reading kernel available
	// system( "package-query -Ss ^linux3[0-9]*$ -f %n > /tmp/kernel_manjaro.txt" );
	if( (fp = popen( "package-query -Ss ^linux[0-9]*$ -f %n", "r" )) == NULL ) { 
		perror( "popen error" );
		exit( 1 );
	}
	while( fgets( buf, sizeof(buf)-1, fp ) != NULL ) {
		if( NULL != ( Ptr = strrchr( buf, '\n' )))
			*Ptr = '\0';
		gtk_combo_box_text_prepend_text( GTK_COMBO_BOX_TEXT(widget), buf );
	}
	pclose( fp );
	gtk_combo_box_set_active( GTK_COMBO_BOX (widget), 0 );
}
// 
// 
void on_label_version_iso_image_realize( GtkWidget *widget, gpointer user_data )
{	
	FILE	*fp;
	size_t 	SizeFile;
	gchar	*Buffer = NULL;
	gint	Cpt;
	gchar	**Larrbuf;
	gchar	*Ptr = NULL;

	// FROM Config.pathname_manjaro_tools_iso_profiles
	// iso_version=0.9.0
	
	if(( SizeFile = libutils_get_size_file( Config.pathname_manjaro_tools_iso_profiles )) > 0 ) {
		if( NULL != ( fp = fopen( Config.pathname_manjaro_tools_iso_profiles, "r" ))) {
			Buffer = (gchar *)g_malloc0( sizeof(gchar) * ( SizeFile +10 ));
			SizeFile = fread( Buffer, SizeFile, 1, fp );			
			fclose( fp );
			
			Larrbuf = g_strsplit( Buffer, "\n", 0 );
			g_free( Buffer );
			Buffer = NULL;
			for( Cpt = 0; Larrbuf[ Cpt ]; Cpt++ ) {
				if( *Larrbuf[ Cpt ] != '\0' )
					if( strstr( Larrbuf[ Cpt ], "dist_release=" )) {  // iso_version
						Ptr = strchr( Larrbuf[ Cpt ], '=' );
						Ptr ++;
						gtk_label_set_label( GTK_LABEL(widget), Ptr );
						break;
					}
			}
			g_strfreev( Larrbuf );
			Larrbuf = NULL;
		}
	}
}
// 
// 
gboolean bool_field = FALSE;
// 
// 
void on_entry_new_version_iso_image_changed( GtkEditable *editable, gpointer user_data )
{
	gchar	*Field = g_strdup( (gchar *)gtk_entry_get_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_new_version_iso_image")) ) );
	gchar	*Ptr = NULL;

	if( FALSE == bool_field ) {
		bool_field = TRUE;
		for( Ptr = &Field[ 0 ]; Ptr && *Ptr; Ptr ++ ) {
			if( FALSE == g_unichar_isdigit( *Ptr ) && *Ptr != '.' ) {
				*Ptr = '\0';
				gtk_entry_set_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_new_version_iso_image")), Field );
				while (gtk_events_pending()) gtk_main_iteration();
				bool_field = FALSE;
				return;
			}
			Ptr ++;
		}
	}
	bool_field = FALSE;
}
// 
// 
void on_entry_new_version_iso_image_realize( GtkWidget *widget, gpointer user_data )
{	
	gtk_entry_set_text( GTK_ENTRY(widget), "" );
}
// 
// 
gchar *NtbKernel_get_dist_release( void )
{
	gchar	*Ptr = (gchar *)gtk_entry_get_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_new_version_iso_image")) );
	
	if( *Ptr == '\0' )
		Ptr = (gchar *)gtk_label_get_label( GTK_LABEL(GLADE_GET_OBJECT("label_version_iso_image")) );
		
	return( (gchar *)Ptr );
}
